package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcWageMapper;
import com.ruoyi.oa.domain.CmcWage;
import com.ruoyi.oa.service.ICmcWageService;

/**
 * 员工工资Service业务层处理
 * 
 * @author cmc
 * @date 2024-09-19
 */
@Service
public class CmcWageServiceImpl implements ICmcWageService 
{
    @Autowired
    private CmcWageMapper cmcWageMapper;

    /**
     * 查询员工工资
     * 
     * @param wageId 员工工资主键
     * @return 员工工资
     */
    @Override
    public CmcWage selectCmcWageByWageId(Integer wageId)
    {
        return cmcWageMapper.selectCmcWageByWageId(wageId);
    }

    /**
     * 查询员工工资列表
     * 
     * @param cmcWage 员工工资
     * @return 员工工资
     */
    @Override
    public List<CmcWage> selectCmcWageList(CmcWage cmcWage)
    {
        return cmcWageMapper.selectCmcWageList(cmcWage);
    }

    /**
     * 新增员工工资
     * 
     * @param cmcWage 员工工资
     * @return 结果
     */
    @Override
    public int insertCmcWage(CmcWage cmcWage)
    {
        return cmcWageMapper.insertCmcWage(cmcWage);
    }

    /**
     * 修改员工工资
     * 
     * @param cmcWage 员工工资
     * @return 结果
     */
    @Override
    public int updateCmcWage(CmcWage cmcWage)
    {
        return cmcWageMapper.updateCmcWage(cmcWage);
    }

    /**
     * 批量删除员工工资
     * 
     * @param wageIds 需要删除的员工工资主键
     * @return 结果
     */
    @Override
    public int deleteCmcWageByWageIds(Integer[] wageIds)
    {
        return cmcWageMapper.deleteCmcWageByWageIds(wageIds);
    }

    /**
     * 批量删除员工工资
     *
     * @param performanceIds 需要删除的员工工资主键
     * @return 结果
     */
    @Override
    public int deleteCmcWageByPerformanceIds(String[] performanceIds)
    {
        return cmcWageMapper.deleteCmcWageByPerformanceIds(performanceIds);
    }

    /**
     * 删除员工工资信息
     * 
     * @param wageId 员工工资主键
     * @return 结果
     */
    @Override
    public int deleteCmcWageByWageId(Integer wageId)
    {
        return cmcWageMapper.deleteCmcWageByWageId(wageId);
    }
}
